@@ -6,10 +6,13 @@ from qualys_etl.etld_lib import etld_lib_credentials as etld_lib_credentials
 from qualys_etl.etld_lib import etld_lib_config as etld_lib_config
 from qualys_etl.etld_lib import etld_lib_functions as etld_lib_functions
 from qualys_etl.etld_lib import etld_lib_extract_transform_load_distribute as etld_lib_extract_transform_load_distribute
+from qualys_etl.etld_lib import etld_lib_sqlite_tables as etld_lib_sqlite_tables
 global xml_files
 global url
 global payload_list
 global qualys_headers
+global host_list_vm_processed_after
+global xml_file
 
 
 def remove_old_files():
@@ -120,43 +123,24 @@ def host_list_extract():
             cred_dict=cred_dict,
             qualys_headers_dict=qualys_headers,
             multi_proc_batch_number=multi_proc_batch_number)
-        # for _ in range(try_extract_max_count):
-        #     try:
-        #         with requests.request("POST", url, stream=True, headers=headers, data=payload, timeout=30) as r:
-        #             #  TODO: grab header and check concurrent connections information
-        #             qualys_headers = etld_lib_credentials.get_qualys_headers(r)
-        #             if r.status_code == 200:
-        #                 with open(xml_file, "w", encoding='utf-8') as f:
-        #                     for chunk in r.iter_content(chunk_size=chunk_size_calc):
-        #                         try:
-        #                             #  TODO: add chunks to queue, use queue limited to last 2, concat and check for errors.
-        #                             f.write(chunk.decode('utf-8'))
-        #                         except Exception as e:
-        #                             f.write(etld_lib_functions.remove_low_high_values(chunk).decode('utf-8'))  # Remove low/high values
-        #             else:
-        #                 if r.status_code == 400:
-        #                     etld_lib_functions.logger.error(f"Validate your Qualys provider tags are correct for provider: {provider}")
-        #                 elif r.status_code == 401:
-        #                     etld_lib_functions.logger.error(f"Validate credentials for user: {cred_dict['username']} url: {url}")
-        #                 elif r.status_code == 409:
-        #                     etld_lib_functions.logger.error(f"Exceeding concurrent connections for endpoint: {url}")
-        #                 else:
-        #                     etld_lib_functions.logger.error(f"HTTP {r.status_code}, exiting. ")
-        #                 exit(1)
-        #     except Exception as e:
-        #         etld_lib_functions.logger.warning(f"Warning for extract xml file: {Path(xml_file).name}")
-        #         etld_lib_functions.logger.warning(f"Warning {e}")
-        #         etld_lib_functions.logger.warning(f"Retry attempt number: {_}")
-        #         time.sleep(10)
-        #         continue
-        #     else:
-        #         break  # success
-        # else:
-        #     etld_lib_functions.logger.error(f"Max retries attempted: {try_extract_max_count}")
-        #     etld_lib_functions.logger.error(f"extract xml file: {Path(xml_file).name}")
-        #     exit(1)
 
 
+def setup_vars_required_for_direct_execution_of_main():
+    global host_list_vm_processed_after
+    global xml_file
+    (min_date, max_date) = etld_lib_sqlite_tables.get_q_table_min_max_dates(
+        etld_lib_config.host_list_sqlite_file,"LAST_VULN_SCAN_DATETIME", "Q_Host_List")
+    etld_lib_functions.logger.info(f"Found Q_Host_List Min Date: {min_date} Max Date: {max_date}")
+    # TODO start from LAST_VULN_SCAN_DATETIME max with seconds set to zero.
+    if max_date == 'Not Found':
+        pass
+    else:
+        pass
+#        host_list_vm_processed_after = re.sub(" .*$", "T00:00:00Z", max_date)  # TODO focus on seconds
+#        etld_lib_functions.logger.info(f"Found host list max date of: {max_date}")
+#        etld_lib_config.host_list_vm_processed_after = host_list_vm_processed_after
+#        etld_lib_functions.logger.info(f"     using host_list_vm_processed_after={host_list_vm_processed_after}")
+
 
 def start_msg_host_list_extract():
     etld_lib_functions.logger.info(f"start ")
