@@ -19,6 +19,7 @@ global logging_level
 global qetl_code_dir        # Parent of qualys_etl directory
 global qetl_code_dir_child  # qualys_etl directory
 global qetl_pip_installed_version  # qetl installed through pip
+import qualys_etl
 
 logging_is_on_flag = False
 
@@ -201,6 +202,7 @@ def get_sqlite_version():
 def setup_logging_stdout(log_level=logging.INFO, my_logger_prog_name=None):
     global logger
     global logging_is_on_flag
+
     logging_is_on_flag = True
     logging.Formatter.converter = time.gmtime
     username = getpass.getuser()
@@ -213,8 +215,9 @@ def setup_logging_stdout(log_level=logging.INFO, my_logger_prog_name=None):
                         )
 
     logger = logging.getLogger()  # Useful in qetl_manage_user when we want to set the name.
+    logger.info(f"PROGRAM:     {sys.argv}")
+    logger.info(f"QUALYSETL VERSION: {qualys_etl.__version__}")
     logger.info(f"LOGGING SUCCESSFULLY SETUP FOR STREAMING")
-    logger.info(f"PROGRAM: {sys.argv}")
 
 
 def setup_logging_to_file(logfile_path, log_level=logging.INFO):
