@@ -111,6 +111,28 @@ def get_q_knowledgebase_min_max_dates(sqlite_file):
     return min_date, max_date
 
 
+def get_q_table_min_max_dates(sqlite_file,datetime_field_name,table_name):
+    min_date = None
+    max_date = None
+    try:
+        conn = sqlite3.connect(sqlite_file)
+        cursor = conn.cursor()
+        select_statement = f'select min({datetime_field_name}) MIN_DATE, ' \
+                           f'max({datetime_field_name}) MAX_DATE ' \
+                           f'from {table_name};'
+        cursor.execute(select_statement)
+        records = cursor.fetchall()
+        for row in records:
+            min_date = row[0]
+            max_date = row[1]
+        conn.close()
+    except Exception as e:
+        min_date = 'Not Found'
+        max_date = 'Not Found'
+
+    return min_date, max_date
+
+
 def create_table_q_knowledgebase_in_host_list_detection(sqlite_file):
     table_name = 'Q_KnowledgeBase_In_Host_List_Detection'
     kb_table_name = 'Q_KnowledgeBase'
