@@ -223,17 +223,15 @@ def test_command_line_arguments():
     # If no options check for -u.  If -u exists, help_message.  If -u does not exist, continue to new user prompts.
     # If -u is not set, help_message
     if results.qetl_user_home_dir is None:
-        help_message(f"\n"
-                     f"Please enter -u [ your opt/qetl/users/ user home directory path ]\n "
-                     f"   Note: opt/qetl/users/newuser is the root directory for your qetl userhome directory, \n"
-                     f"         enter a new path including the opt/qetl/users/newuser \n"
-                     f"         in the path you have authorization to write to.\n"
-                     f"         the prefix to your user directory opt/qetl/users is required.\n"
-                     f"         Examples:\n"
-                     f"            1) /usr/local/opt/qetl/users/newuser\n"
-                     f"            2) /opt/qetl/users/newuser\n"
-                     f"            3) /somepath/opt/qetl/users/newuser\n"
-                     f"\n")
+        help_message(f" "
+                     f"Please enter -u [ your opt/qetl/users/ user home directory path ]\n"
+                     f"    Note: opt/qetl/users/newuser is the root directory for your qetl userhome directory,\n" 
+                     f"          enter a new path including the opt/qetl/users/newuser \n"
+                     f"           in the path you have authorization to write to.\n"
+                     f"           the prefix to your user directory opt/qetl/users is required.\n"
+                     f"    Example:\n"
+                     f"             qetl_manage_user -u /opt/qetl/users/[your_user_name]\n"
+                     f" ")
         exit(6)  # 6 is for testing the command works. Ex. qetl_manage_user; if [[ "$?" == "6"]]; then : ...
 
     test_qetl_user_home_dir = Path(results.qetl_user_home_dir).absolute()
